@@ -392,7 +392,7 @@ from ae.core import DEBUG_LEVELS, registered_app_names
 from ae.console import ConsoleApp                                                                       # type: ignore
 
 
-__version__ = '0.1.70'
+__version__ = '0.1.71'
 
 
 AppStateType = Dict[str, Any]                   #: app state config variable type
@@ -410,8 +410,8 @@ THEME_DARK_FONT_COLOR = COLOR_WHITE             #: dark theme font color in rgba
 THEME_LIGHT_BACKGROUND_COLOR = COLOR_WHITE      #: light theme background color in rgba(0.0 ... 1.0)
 THEME_LIGHT_FONT_COLOR = COLOR_BLACK            #: light theme font color in rgba(0.0 ... 1.0)
 
-MIN_FONT_SIZE = 15.0                            #: minimum font size in pixels
-MAX_FONT_SIZE = 99.0                            #: maximum font size in pixels
+MIN_FONT_SIZE = 15.0                            #: minimum (s.a. :attr:`~ae.kivy_app.FrameworkApp.min_font_size`) and
+MAX_FONT_SIZE = 99.0                            #: .. maximum font size in pixels
 
 
 ACTIONS_EXTENDING_FLOW_PATH = ['add', 'confirm', 'edit', 'enter', 'open', 'show', 'suggest']
